<?php
/**
 ************************************************************************
 * Copyright (c) 2005-2020 Stefan (Muetze) Horst                        *
 ************************************************************************
 * I don't have the time to read through all the licences to find out   *
 * what the exactly say. But it's simple. It's free for non commercial  *
 * projects, but as soon as you make money with it, i want my share :-) *
 * (License : Free for non-commercial use)                              *
 ************************************************************************
 * Authors: Stefan (Muetze) Horst <muetze@DPSG-Liblar.de>               *
 ************************************************************************
 */


namespace Drupal\scoutnet_kalender\Plugin\Block;


use Drupal\Core\Block\BlockBase;
use Drupal\Core\Block\BlockPluginInterface;
use Drupal\Core\Form\FormStateInterface;
use ScoutNet\Api\ScoutnetApi;

/**
 * Provides a 'ScoutNet Kalender' Block.
 *
 * @Block(
 *   id = "scoutnet_kalender_block",
 *   admin_label = @Translation("ScoutNet Kalender block"),
 *   category = @Translation("ScoutNet"),
 * )
 */
class KalenderBlock extends BlockBase implements BlockPluginInterface {

    /**
     * @inheritDoc
     */
    public function build() {
        $ssids = array_map('intval', array_map('trim', explode(',', $this->configuration['snk_block_ssid'] ?? '2195,2220')));

        $filter = [
            'limit' => intval($this->configuration['snk_block_limit'] ?? '3'),
            'after' => 'now()',
        ];

        $cat = [];
        if (!empty($this->configuration['snk_block_categories']) && trim($this->configuration['snk_block_categories'])) {
            $cat = array_map('intval', array_map('trim', explode(',', $this->configuration['snk_block_categories'])));
            $filter['kategories']  = $cat;
        }

        $scoutNetApi = new ScoutnetApi();
        $events = $scoutNetApi->get_events_for_global_id_with_filter($ssids, $filter);
        $structures = $scoutNetApi->get_kalender_by_global_id($ssids);

        $categories = [];
        if (count($cat) > 0) {
            $categories = $scoutNetApi->get_categories_by_ids($cat);
        }

        $text = '';
        foreach ($events as $event) {
            $text .= $event->getTitle()."<br>";
        }

        return [
            '#theme' => 'snk_block',
            '#events' => $events,
            '#structures' => $structures,
//            '#optionalStructures' => $optional_structures,
            '#categories' => $categories,
//            '#optionalCategories' => $optional_categories,
        ];
    }

    /**
     * @inheritDoc
     */
    public function blockForm($form, FormStateInterface $form_state) {
        $form = parent::blockForm($form, $form_state); // TODO: Change the autogenerated stub
        $config = $this->getConfiguration();

        $form['snk_block_ssid'] = [
            '#type' => 'textfield',
            '#title' => $this->t('Kalender SSIDs'),
            '#description' => $this->t('Which Calendars do you want to show? Seperated by comma.'),
            '#default_value' => isset($config['snk_block_ssid']) ? $config['snk_block_ssid'] : '2195,2220',
        ];

//        $form['snk_block_optional_ssid'] = [
//            '#type' => 'textfield',
//            '#title' => $this->t('Optional Kalender SSIDs'),
//            '#description' => $this->t('Which Calendars do you want the User to choose from? Seperated by comma.'),
//            '#default_value' => isset($config['snk_block_optional_ssid']) ? $config['snk_block_optional_ssid'] : '',
//        ];

        $form['snk_block_categories'] = [
            '#type' => 'textfield',
            '#title' => $this->t('Kalender Category IDs'),
            '#description' => $this->t('Which Categories do you want to show? Seperated by comma.'),
            '#default_value' => isset($config['snk_block_categories']) ? $config['snk_block_categories'] : '',
        ];
//        $form['snk_block_optional_categories'] = [
//            '#type' => 'textfield',
//            '#title' => $this->t('Optional Kalender Category IDs'),
//            '#description' => $this->t('Which Categories do you want the User to choose from? Seperated by comma.'),
//            '#default_value' => isset($config['snk_block_optional_categories']) ? $config['snk_block_optional_categories'] : '',
//        ];

        $form['snk_block_limit'] = [
            '#type' => 'textfield',
            '#title' => $this->t('Nr. of Events'),
            '#description' => $this->t('How many Events do you want to show?'),
            '#default_value' => isset($config['snk_block_limit']) ? $config['snk_block_limit'] : '3',
        ];

        return $form;
    }

    /**
     * {@inheritdoc}
     */
    public function blockSubmit($form, FormStateInterface $form_state) {
        parent::blockSubmit($form, $form_state);
        $values = $form_state->getValues();
        $this->configuration['snk_block_ssid'] = $values['snk_block_ssid'];
        $this->configuration['snk_block_optional_ssid'] = $values['snk_block_optional_ssid'];
        $this->configuration['snk_block_categories'] = $values['snk_block_categories'];
        $this->configuration['snk_block_optional_categories'] = $values['snk_block_optional_categories'];
        $this->configuration['snk_block_limit'] = $values['snk_block_limit'];
    }

}